      IMPLICIT NONE
      LOGICAL ERROR
      CHARACTER*12 FORM
      DATA ERROR /.FALSE./
      DATA FORM  /' '/
      OPEN(UNIT=60,ACCESS='DIRECT',STATUS='SCRATCH',RECL=255)
      INQUIRE(UNIT=60,FORM=FORM)
      IF (FORM.EQ.'UNFORMATTED') THEN
         ERROR = .FALSE.
      ELSE
         ERROR = .TRUE.
      ENDIF
      CLOSE(UNIT=60)
      IF (ERROR) CALL ABORT
      END
