-- C41326A.ADA

--                             Grant of Unlimited Rights
--
--     Under contracts F33600-87-D-0337, F33600-84-D-0280, MDA903-79-C-0687,
--     F08630-91-C-0015, and DCA100-97-D-0025, the U.S. Government obtained 
--     unlimited rights in the software and documentation contained herein.
--     Unlimited rights are defined in DFAR 252.227-7013(a)(19).  By making 
--     this public release, the Government intends to confer upon all 
--     recipients unlimited rights  equal to those held by the Government.  
--     These rights include rights to use, duplicate, release or disclose the 
--     released technical data and computer software in whole or in part, in 
--     any manner and for any purpose whatsoever, and to have or permit others 
--     to do so.
--
--                                    DISCLAIMER
--
--     ALL MATERIALS OR INFORMATION HEREIN RELEASED, MADE AVAILABLE OR
--     DISCLOSED ARE AS IS.  THE GOVERNMENT MAKES NO EXPRESS OR IMPLIED 
--     WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING THE CONDITIONS OF THE
--     SOFTWARE, DOCUMENTATION OR OTHER INFORMATION RELEASED, MADE AVAILABLE 
--     OR DISCLOSED, OR THE OWNERSHIP, MERCHANTABILITY, OR FITNESS FOR A
--     PARTICULAR PURPOSE OF SAID MATERIAL.
--*
-- CHECK THAT IMPLICITLY DECLARED EQUALITY AND INEQUALITY OPERATORS
-- MAY BE SELECTED FROM OUTSIDE A PACKAGE USING AN EXPANDED NAME, FOR
-- AN ACCESS TYPE.

-- TBN  7/18/86

WITH REPORT; USE REPORT;
PROCEDURE C41326A IS

     PACKAGE P IS
          TYPE CELL IS
               RECORD
                    VALUE : INTEGER;
               END RECORD;
          TYPE LINK IS ACCESS CELL;

          OBJ_LINK_1 : LINK := NEW CELL'(VALUE => 1);
          OBJ_LINK_2 : LINK := OBJ_LINK_1;
     END P;

     VAR_LINK_1 : P.LINK := NEW P.CELL'(VALUE => 1);
     VAR_LINK_2 : P.LINK := NEW P.CELL'(VALUE => 2);

BEGIN
     TEST ("C41326A", "CHECK THAT IMPLICITLY DECLARED EQUALITY AND " &
                      "INEQUALITY OPERATORS MAY BE SELECTED FROM " &
                      "OUTSIDE A PACKAGE USING AN EXPANDED NAME, " &
                      "FOR AN ACCESS TYPE");

     IF P."=" (VAR_LINK_1, P.OBJ_LINK_1) THEN
          FAILED ("INCORRECT RESULTS FROM EXPANDED NAME - 1");
     END IF;

     IF P."/=" (P.OBJ_LINK_1, P.OBJ_LINK_2) THEN
          FAILED ("INCORRECT RESULTS FROM EXPANDED NAME - 2");
     END IF;

     IF P."=" (VAR_LINK_2.ALL, P.OBJ_LINK_1.ALL) THEN
          FAILED ("INCORRECT RESULTS FROM EXPANDED NAME - 3");
     END IF;

     VAR_LINK_2.VALUE := 1;
     IF P."/=" (VAR_LINK_2.ALL, P.OBJ_LINK_1.ALL) THEN
          FAILED ("INCORRECT RESULTS FROM EXPANDED NAME - 4");
     END IF;

     RESULT;
END C41326A;
