// { dg-do assemble  }
// { dg-options "-g" }
// Origin: Jim Wilson <wilson@cygnus.com>

template<template<class> class _Oper,
    template<class, class> class _Meta1,
    template<class, class> class _Meta2,
    class _Dom1, class _Dom2> class _BinClos;
